@@ -38,6 +38,7 @@ class Element(object):
         :param results: The results list returned by Rexster.
 
         """
+        self._data = {}
         self.resource = resource
         self._set_element_data(results)
         self._gremlin = Gremlin(self.resource)
@@ -396,13 +397,32 @@ class Edge(Element):
     def _outV(self):
         """Returns the outgoing vertex ID of the edge."""
         #return int(self._data['_outV'])
-        return utils.coerce_id(self._data['_outV'])
+        _outV = self._data.get('_outV')
+        if _outV is None and hasattr(self,"__outV"):
+            _outV = self.__outV
+        return utils.coerce_id(_outV)
+
+    @_outV.setter
+    def _outV(self, value):
+        self.__outV = value
         
     @property
     def _inV(self):
         """Returns the incoming vertex ID of the edge."""
         #return int(self._data['_inV'])
-        return utils.coerce_id(self._data['_inV'])
+        #return utils.coerce_id(self._data['_inV'])
+        _inV = self._data.get('_inV')
+        if _inV is None and hasattr(self,"__inV"):
+            _inV = self.__inV
+        return utils.coerce_id(_inV)
+
+    @_inV.setter
+    def _inV(self, value):
+     #   _inV = EdgeProxy(self.resource)._coerce_vertex_id(value)
+     #   super(Element, self).__setattr__("_inV", _inV)
+     #   #EdgeProxy(self.resource)._coerce_vertex_id(value)
+        #super(Element, self).__setattr__("_inV", value)
+        self.__inV = value
 
     # TODO: Make outV and inV return a specific Model class and not a generic 
     # Vertex
@@ -419,7 +439,14 @@ class Edge(Element):
     @property
     def label(self):
         """Returns the edge's label."""
-        return self._label
+        _label = self._data.get('_label')
+        if _label is None and hasattr(self,"__label"):
+            _label = self.__label
+        return _label
+
+    @label.setter
+    def label(self,value):
+        self.__label = value
 
 
 class ElementProxy(object):
@@ -493,15 +520,23 @@ class ElementProxy(object):
             return resp
         return self.element_class(self.resource,resp.results)
 
-    def get(self,_id):
+    def get(self,_id,raw=False):
         """ 
         Retrieves an element from Rexster and returns it. 
         
         :param _id: The ID of the element you want to retrieve.
 
+        :param raw: Optional keyword param. If raw is False (which is the 
+                    default) it will try to instantiate the element to the 
+                    element_class specified when the proxy object was created.
+                    However, if the raw param is set to True, it will won't 
+                    instantiate the object and will return the raw Response 
+                    object.
         """
         target = "%s/%s" % (self._base_target(),_id)
         resp = self.resource.get(target,params=None)
+        if raw is True:
+            return resp
         if resp.results:
             return self.element_class(self.resource,resp.results)        
     
