@@ -36,7 +36,8 @@ class Graph(object):
 
     """
 
-    def __init__(self,db_url=config.DATABASE_URL):
+    def __init__(self,db_url=None):
+        db_url = db_url if db_url else config.DATABASE_URL
         self.resource = Resource(db_url)
         self.vertices = VertexProxy(self.resource)
         self.edges = EdgeProxy(self.resource)
@@ -155,7 +156,6 @@ class Graph(object):
             element_class = class_map[index_name]
             return (element_class(self.resource,result) for result in resp.results)
 
-    
     def load_graphml(self,url):
         """
         Loads a GraphML file into the database, and returns the Rexster 
@@ -165,8 +165,7 @@ class Graph(object):
 
         """
         script = "g.loadGraphML('%s')" % url
-        params = dict(script=script)
-        resp = self.resource.get(self.base_target,params)
+        resp = self.gremlin.execute(script)
         return resp
 
     def save_graphml(self):
@@ -179,9 +178,8 @@ class Graph(object):
         g.saveGraphML('data/graphml');
         new File('data/graphml').getText();
         """
-        params = dict(script=script)
-        resp = self.resource.get(self.base_target,params)
-        return resp.results
+        results = self.gremlin.execute(script)
+        return results[0]
 
     def clear(self):
         """
