@@ -14,7 +14,7 @@ import urllib2
 import httplib2
 import simplejson as json
 from urlparse import urlsplit
-from posixpath import basename
+from posixpath import split
 import config
 
 DEBUG = config.DEBUG
@@ -30,13 +30,14 @@ class Resource(object):
         :param db_url: the base URL of Rexster.
 
         """
-        self.db_url = db_url
-        if db_url.endswith("/"):
-            # strip off trailing slash
-            db_url = db_url[:-1]
-        url_object = urlsplit(db_url)
-        self.base_url = "%s://%s" % (url_object.scheme,url_object.netloc)
-        self.db_name = basename(url_object.path)        
+
+        #print "DB_URL", db_url
+        # strip off trailing slash
+        self.db_url = db_url.rstrip('/')
+        url_object = urlsplit(self.db_url)
+        root_path, self.db_name = split(url_object.path)
+        self.base_url = "%s://%s%s" % (url_object.scheme, url_object.netloc, root_path)
+        self.http = httplib2.Http()
 
     def get(self,target,params):
         """Convenience method that sends GET requests to the resource.""" 
@@ -64,7 +65,7 @@ class Resource(object):
         assert method in ("GET","POST","DELETE"), \
             "Only GET, POST, DELETE are allowed."
 
-        headers = {'Accept': 'application/json', 'connection': 'close'}
+        headers = {'Accept': 'application/json'}
 
         # httplib2 let's you cache http responses with memcache 
         # really cool, look into that later
@@ -87,9 +88,8 @@ class Resource(object):
 
         attempt = 0
         ok = False
-        http = httplib2.Http()       
         while not ok and (attempt < MAX_RETRIES):
-            resp = Response(http.request(url, method, body, headers))
+            resp = Response(self.http.request(url, method, body, headers))
             attempt += 1
             ok = resp.ok            
 
